@@ -1,12 +1,13 @@
 package QBit::WebInterface;
-$QBit::WebInterface::VERSION = '0.027';
+$QBit::WebInterface::VERSION = '0.028';
 use POSIX qw(strftime setlocale LC_TIME);
 
 use qbit;
 
 use QBit::WebInterface::Response;
 
-eval {require Exception::WebInterface::Controller::CSRF; require Exception::Request::UnknownMethod};
+use Exception::WebInterface::Controller::CSRF;
+use Exception::Request::UnknownMethod;
 
 sub request {
     my ($self, $request) = @_;
