@@ -1,13 +1,11 @@
-package Exception::WebInterface::Controller::CSRF;
-$Exception::WebInterface::Controller::CSRF::VERSION = '0.027';
-use base qw(Exception);
-
 package QBit::WebInterface::Controller;
-$QBit::WebInterface::Controller::VERSION = '0.027';
+$QBit::WebInterface::Controller::VERSION = '0.028';
 use qbit;
 
 use base qw(QBit::Application::Part);
 
+use Exception::WebInterface::Controller::CSRF;
+
 use Template 2.20;
 use Template::Config;
 use Digest::MD5 qw(md5_hex);
