@@ -1,10 +1,10 @@
 package QBit::WebInterface::Controller::Form::Field;
-$QBit::WebInterface::Controller::Form::Field::VERSION = '0.027';
+$QBit::WebInterface::Controller::Form::Field::VERSION = '0.028';
 use qbit;
 
 use base qw(QBit::Class);
 
-eval {require Exception::Form};
+use Exception::Form;
 
 __PACKAGE__->mk_accessors(qw(form name value));
 __PACKAGE__->abstract_methods(qw(control_html));
