@@ -1,10 +1,10 @@
 package QBit::WebInterface::Controller::Form::Field::email;
-$QBit::WebInterface::Controller::Form::Field::email::VERSION = '0.027';
+$QBit::WebInterface::Controller::Form::Field::email::VERSION = '0.028';
 use qbit;
 
 use base qw(QBit::WebInterface::Controller::Form::Field::input);
 
-eval {require Exception::Form};
+use Exception::Form;
 
 sub init {
     my ($self) = @_;
